@@ -2,7 +2,7 @@ from django.apps import AppConfig
 
 
 class DjangoToolsConfig(AppConfig):
-    name = 'django_toolshed'
+    name = "django_toolshed"
 
     def ready(self):
         try:
