@@ -1,5 +1,5 @@
 from django.urls import path
 
-app_name = 'django_toolshed'
+app_name = "django_toolshed"
 
 urlpatterns = []
